@@ -11,10 +11,13 @@ import logging
 # Models for loading recipes, and for generating looker data from the combination of 
 # the database and the recipes
 
-def ji2(search, values):
+def ji2(search, values, value=None):
     """Jinja2 render function"""
     jinja_env = Environment()
-    target = values.get(search, None)
+    if value is not None:
+        target = value
+    else:
+        target = values.get(search, None)
     if target is None:
         return target
     else:
@@ -63,10 +66,12 @@ class LookerMixtureMeasure(LookerMeasure):
     def fix_name(cls, values):
         values["name"] = f"m_{values.get('type')}_{values.get('parent_name')}"
 
+        if values.get("alias") is not None:
+            values["alias"] = [ji2("alias", values, value=v) for v in values.get("alias")]
         if values.get("sql") is not None:
             values["sql"] = ji2("sql", values)
-        if values.get("html") is not None:
-            values["html"] =  ji2("html", values)
+        # if values.get("html") is not None:
+            # values["html"] =  ji2("html", values)
         if values.get("label") is not None:
             values["label"] = ji2("label", values)
         if values.get("group_label") is not None:
@@ -84,6 +89,10 @@ class LookerMixtureMeasure(LookerMeasure):
             values["description"] = f"{values.get('type')} of {values.get("parent_name")} : {values.get("parent_description")}"
         if values.get("value_format_name") is None:
             values["value_format_name"] = values.get("parent_value_format_name")
+        if values.get("value_format") is None:
+            values["value_format"] = values.get("parent_value_format")
+        if values.get("hidden") is None:
+            values["hidden"] = values.get("parent_hidden")
         values["type"] = values.get("type", values.get("parent_type", "number"))
         return values
 
@@ -99,6 +108,7 @@ class LookerMixtureDimension(LookerRecipeDimension):
     def create(cls, values):
 
         def push_down(field : dict, list_params : List[str]):
+            """ push down parent information to a child field as prefixed parent_{param} information """
             for param in list_params:
                 field[f"parent_{param}"] = values.get(param)
                 if param == "label":
@@ -108,35 +118,40 @@ class LookerMixtureDimension(LookerRecipeDimension):
         if values.get("measures") is not None:
             inherited_children = []
             for child in values.get("measures", []):
-                child = push_down(child, ["name", "sql", "type", "group_label", "description", "tags", "value_format_name", "label"])
+                child = push_down(child, ["name", "sql", "type", "group_label", "description", "tags", "value_format_name", "value_format", "label", "hidden"])
                 inherited_children.append(child)
             values["measures"] = inherited_children
 
         if values.get("variants") is not None:
             inherited_children = []
             for child in values.get("variants", []):
-                child = push_down(child, ["name", "sql", "type", "group_label", "description", "tags", "value_format_name", "label"])
+                child = push_down(child, ["name", "sql", "type", "group_label", "description", "tags", "value_format_name", "value_format", "label", "hidden"])
                 inherited_children.append(child)
             values["variants"] = inherited_children
         return values
 
     @model_validator(mode="before")
     def fix_name(cls, values):
+        if values.get("alias") is not None:
+            values["alias"] = [ji2("alias", values, value=v) for v in values.get("alias")]
+        if values.get("sql") is not None:
+            values["sql"] = ji2("sql", values)
+        if values.get("suggest_dimension") is not None:
+            values["suggest_dimension"] = ji2("suggest_dimension", values)
+        if values.get("suggest_explore") is not None:
+            values["suggest_explore"] = ji2("suggest_explore", values)
+        # if values.get("html") is not None:
+            # values["html"] = ji2("html", values)
+        if values.get("label") is not None:
+            values["label"] = ji2("label", values)
+        if values.get("group_label") is not None:
+            values["group_label"] = ji2("group_label", values)
+        if values.get("description") is not None:
+            values["description"] = ji2("description", values)
+        if values.get("group_item_label") is None:
+            values["group_item_label"] = ji2("group_item_label", values)
+
         if values.get("suffix") is not None:
-
-            if values.get("sql") is not None:
-                values["sql"] = ji2("sql", values)
-            if values.get("html") is not None:
-                values["html"] = ji2("html", values)
-            if values.get("label") is not None:
-                values["label"] = ji2("label", values)
-            if values.get("group_label") is not None:
-                values["group_label"] = ji2("group_label", values)
-            if values.get("description") is not None:
-                values["description"] = ji2("description", values)
-            if values.get("group_item_label") is None:
-                values["group_item_label"] = ji2("group_item_label", values)
-
             values["name"] = f"d_{values.get('parent_name')}_{values.get('suffix')}"
             if values.get("remove") != "" and values.get("remove") is not None:
                 values["name"] = values["name"].replace(values.get("remove"), "")
@@ -146,6 +161,10 @@ class LookerMixtureDimension(LookerRecipeDimension):
                 values["description"] = f"derived {values.get('suffix')} of {values.get("parent_name")} : {values.get("parent_description")}"
             if values.get("value_format_name") is None:
                 values["value_format_name"] = values.get("parent_value_format_name", "string")
+            if values.get("value_format") is None:
+                values["value_format"] = values.get("parent_value_format")
+            if values.get("hidden") is None:
+                values["hidden"] = values.get("parent_hidden")
             values["type"] = values.get("type", values.get("parent_type", "string"))
         return values
 
@@ -161,14 +180,18 @@ class LookerMixture(BaseModel):
 class RecipeFilter(BaseModel):
     """a filter for a recipe"""
 
-    type: Optional[LookerType] = None
-    db_type: Optional[str] = None
+    types: Optional[List[LookerType]] = None
+    db_types: Optional[List[str]] = None
     regex_include: Optional[str] = None
     regex_exclude: Optional[str] = None
     tags: Optional[List[str]] = None
     fields_include: Optional[List[str]] = None
     fields_exclude: Optional[List[str]] = None
     field_order: Optional[List[int]] = None
+    is_nested: Optional[bool] = False
+    depth: Optional[List[int]] = None
+    table_regex_include: Optional[str] = None
+    table_regex_exclude: Optional[str] = None
 
     @model_validator(mode="before")
     def check_at_least_one_field(cls, values):
